# coding: utf-8

"""
    Data Repository API

    <details><summary>This document defines the REST API for the Terra Data Repository.</summary> <p> **Status: design in progress** There are a few top-level endpoints (besides some used by swagger):  * / - generated by swagger: swagger API page that provides this documentation and a live UI for submitting REST requests  * /status - provides the operational status of the service  * /configuration - provides the basic configuration and information about the service  * /api - is the authenticated and authorized Data Repository API  * /ga4gh/drs/v1 - is a transcription of the Data Repository Service API  The API endpoints are organized by interface. Each interface is separately versioned. <p> **Notes on Naming** <p> All of the reference items are suffixed with \\\"Model\\\". Those names are used as the class names in the generated Java code. It is helpful to distinguish these model classes from other related classes, like the DAO classes and the operation classes. </details>   # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from data_repo_client.configuration import Configuration


class BulkLoadResultModel(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'load_tag': 'str',
        'job_id': 'str',
        'total_files': 'int',
        'succeeded_files': 'int',
        'failed_files': 'int',
        'not_tried_files': 'int'
    }

    attribute_map = {
        'load_tag': 'loadTag',
        'job_id': 'jobId',
        'total_files': 'totalFiles',
        'succeeded_files': 'succeededFiles',
        'failed_files': 'failedFiles',
        'not_tried_files': 'notTriedFiles'
    }

    def __init__(self, load_tag=None, job_id=None, total_files=None, succeeded_files=None, failed_files=None, not_tried_files=None, local_vars_configuration=None):  # noqa: E501
        """BulkLoadResultModel - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._load_tag = None
        self._job_id = None
        self._total_files = None
        self._succeeded_files = None
        self._failed_files = None
        self._not_tried_files = None
        self.discriminator = None

        if load_tag is not None:
            self.load_tag = load_tag
        if job_id is not None:
            self.job_id = job_id
        if total_files is not None:
            self.total_files = total_files
        if succeeded_files is not None:
            self.succeeded_files = succeeded_files
        if failed_files is not None:
            self.failed_files = failed_files
        if not_tried_files is not None:
            self.not_tried_files = not_tried_files

    @property
    def load_tag(self):
        """Gets the load_tag of this BulkLoadResultModel.  # noqa: E501

        client-specified tag for a data or file load. If no id is specified, we use the string form of the job create time as the tag.   # noqa: E501

        :return: The load_tag of this BulkLoadResultModel.  # noqa: E501
        :rtype: str
        """
        return self._load_tag

    @load_tag.setter
    def load_tag(self, load_tag):
        """Sets the load_tag of this BulkLoadResultModel.

        client-specified tag for a data or file load. If no id is specified, we use the string form of the job create time as the tag.   # noqa: E501

        :param load_tag: The load_tag of this BulkLoadResultModel.  # noqa: E501
        :type: str
        """

        self._load_tag = load_tag

    @property
    def job_id(self):
        """Gets the job_id of this BulkLoadResultModel.  # noqa: E501


        :return: The job_id of this BulkLoadResultModel.  # noqa: E501
        :rtype: str
        """
        return self._job_id

    @job_id.setter
    def job_id(self, job_id):
        """Sets the job_id of this BulkLoadResultModel.


        :param job_id: The job_id of this BulkLoadResultModel.  # noqa: E501
        :type: str
        """

        self._job_id = job_id

    @property
    def total_files(self):
        """Gets the total_files of this BulkLoadResultModel.  # noqa: E501


        :return: The total_files of this BulkLoadResultModel.  # noqa: E501
        :rtype: int
        """
        return self._total_files

    @total_files.setter
    def total_files(self, total_files):
        """Sets the total_files of this BulkLoadResultModel.


        :param total_files: The total_files of this BulkLoadResultModel.  # noqa: E501
        :type: int
        """

        self._total_files = total_files

    @property
    def succeeded_files(self):
        """Gets the succeeded_files of this BulkLoadResultModel.  # noqa: E501


        :return: The succeeded_files of this BulkLoadResultModel.  # noqa: E501
        :rtype: int
        """
        return self._succeeded_files

    @succeeded_files.setter
    def succeeded_files(self, succeeded_files):
        """Sets the succeeded_files of this BulkLoadResultModel.


        :param succeeded_files: The succeeded_files of this BulkLoadResultModel.  # noqa: E501
        :type: int
        """

        self._succeeded_files = succeeded_files

    @property
    def failed_files(self):
        """Gets the failed_files of this BulkLoadResultModel.  # noqa: E501


        :return: The failed_files of this BulkLoadResultModel.  # noqa: E501
        :rtype: int
        """
        return self._failed_files

    @failed_files.setter
    def failed_files(self, failed_files):
        """Sets the failed_files of this BulkLoadResultModel.


        :param failed_files: The failed_files of this BulkLoadResultModel.  # noqa: E501
        :type: int
        """

        self._failed_files = failed_files

    @property
    def not_tried_files(self):
        """Gets the not_tried_files of this BulkLoadResultModel.  # noqa: E501


        :return: The not_tried_files of this BulkLoadResultModel.  # noqa: E501
        :rtype: int
        """
        return self._not_tried_files

    @not_tried_files.setter
    def not_tried_files(self, not_tried_files):
        """Sets the not_tried_files of this BulkLoadResultModel.


        :param not_tried_files: The not_tried_files of this BulkLoadResultModel.  # noqa: E501
        :type: int
        """

        self._not_tried_files = not_tried_files

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BulkLoadResultModel):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, BulkLoadResultModel):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

# flake8: noqa

"""
    Data Repository API

    <details><summary>This document defines the REST API for the Terra Data Repository.</summary> <p> **Status: design in progress** There are a few top-level endpoints (besides some used by swagger):  * / - generated by swagger: swagger API page that provides this documentation and a live UI for submitting REST requests  * /status - provides the operational status of the service  * /configuration - provides the basic configuration and information about the service  * /api - is the authenticated and authorized Data Repository API  * /ga4gh/drs/v1 - is a transcription of the Data Repository Service API  The API endpoints are organized by interface. Each interface is separately versioned. <p> **Notes on Naming** <p> All of the reference items are suffixed with \\\"Model\\\". Those names are used as the class names in the generated Java code. It is helpful to distinguish these model classes from other related classes, like the DAO classes and the operation classes. </details>   # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

__version__ = "2.59.0"

# import apis into sdk package
from data_repo_client.api.data_repository_service_api import DataRepositoryServiceApi
from data_repo_client.api.snapshot_access_request_api import SnapshotAccessRequestApi
from data_repo_client.api.admin_api import AdminApi
from data_repo_client.api.configs_api import ConfigsApi
from data_repo_client.api.datasets_api import DatasetsApi
from data_repo_client.api.duos_api import DuosApi
from data_repo_client.api.jobs_api import JobsApi
from data_repo_client.api.journal_api import JournalApi
from data_repo_client.api.profiles_api import ProfilesApi
from data_repo_client.api.register_api import RegisterApi
from data_repo_client.api.repository_api import RepositoryApi
from data_repo_client.api.resources_api import ResourcesApi
from data_repo_client.api.search_api import SearchApi
from data_repo_client.api.snapshots_api import SnapshotsApi
from data_repo_client.api.unauthenticated_api import UnauthenticatedApi
from data_repo_client.api.upgrade_api import UpgradeApi

# import ApiClient
from data_repo_client.api_client import ApiClient
from data_repo_client.configuration import Configuration
from data_repo_client.exceptions import OpenApiException
from data_repo_client.exceptions import ApiTypeError
from data_repo_client.exceptions import ApiValueError
from data_repo_client.exceptions import ApiKeyError
from data_repo_client.exceptions import ApiException
# import models into sdk package
from data_repo_client.models.access_info_big_query_model import AccessInfoBigQueryModel
from data_repo_client.models.access_info_big_query_model_table import AccessInfoBigQueryModelTable
from data_repo_client.models.access_info_model import AccessInfoModel
from data_repo_client.models.access_info_parquet_model import AccessInfoParquetModel
from data_repo_client.models.access_info_parquet_model_table import AccessInfoParquetModelTable
from data_repo_client.models.add_auth_domain_response_model import AddAuthDomainResponseModel
from data_repo_client.models.asset_model import AssetModel
from data_repo_client.models.asset_table_model import AssetTableModel
from data_repo_client.models.billing_profile_model import BillingProfileModel
from data_repo_client.models.billing_profile_request_model import BillingProfileRequestModel
from data_repo_client.models.billing_profile_update_model import BillingProfileUpdateModel
from data_repo_client.models.bulk_load_array_request_model import BulkLoadArrayRequestModel
from data_repo_client.models.bulk_load_array_result_model import BulkLoadArrayResultModel
from data_repo_client.models.bulk_load_file_model import BulkLoadFileModel
from data_repo_client.models.bulk_load_file_result_model import BulkLoadFileResultModel
from data_repo_client.models.bulk_load_file_state import BulkLoadFileState
from data_repo_client.models.bulk_load_history_model import BulkLoadHistoryModel
from data_repo_client.models.bulk_load_history_model_list import BulkLoadHistoryModelList
from data_repo_client.models.bulk_load_request_model import BulkLoadRequestModel
from data_repo_client.models.bulk_load_result_model import BulkLoadResultModel
from data_repo_client.models.cloud_platform import CloudPlatform
from data_repo_client.models.column_model import ColumnModel
from data_repo_client.models.column_statistics_double_model import ColumnStatisticsDoubleModel
from data_repo_client.models.column_statistics_double_model_all_of import ColumnStatisticsDoubleModelAllOf
from data_repo_client.models.column_statistics_int_model import ColumnStatisticsIntModel
from data_repo_client.models.column_statistics_int_model_all_of import ColumnStatisticsIntModelAllOf
from data_repo_client.models.column_statistics_model import ColumnStatisticsModel
from data_repo_client.models.column_statistics_text_model import ColumnStatisticsTextModel
from data_repo_client.models.column_statistics_text_model_all_of import ColumnStatisticsTextModelAllOf
from data_repo_client.models.column_statistics_text_value import ColumnStatisticsTextValue
from data_repo_client.models.config_enable_model import ConfigEnableModel
from data_repo_client.models.config_fault_counted_model import ConfigFaultCountedModel
from data_repo_client.models.config_fault_model import ConfigFaultModel
from data_repo_client.models.config_group_model import ConfigGroupModel
from data_repo_client.models.config_list_model import ConfigListModel
from data_repo_client.models.config_model import ConfigModel
from data_repo_client.models.config_parameter_model import ConfigParameterModel
from data_repo_client.models.drs_access_method import DRSAccessMethod
from data_repo_client.models.drs_access_url import DRSAccessURL
from data_repo_client.models.drs_authorizations import DRSAuthorizations
from data_repo_client.models.drs_checksum import DRSChecksum
from data_repo_client.models.drs_contents_object import DRSContentsObject
from data_repo_client.models.drs_error import DRSError
from data_repo_client.models.drs_object import DRSObject
from data_repo_client.models.drs_passport_request_model import DRSPassportRequestModel
from data_repo_client.models.drs_service_info import DRSServiceInfo
from data_repo_client.models.data_deletion_gcs_file_model import DataDeletionGcsFileModel
from data_repo_client.models.data_deletion_json_array_model import DataDeletionJsonArrayModel
from data_repo_client.models.data_deletion_request import DataDeletionRequest
from data_repo_client.models.data_deletion_table_model import DataDeletionTableModel
from data_repo_client.models.dataset_data_model import DatasetDataModel
from data_repo_client.models.dataset_model import DatasetModel
from data_repo_client.models.dataset_patch_request_model import DatasetPatchRequestModel
from data_repo_client.models.dataset_request_access_include_model import DatasetRequestAccessIncludeModel
from data_repo_client.models.dataset_request_model import DatasetRequestModel
from data_repo_client.models.dataset_request_model_policies import DatasetRequestModelPolicies
from data_repo_client.models.dataset_schema_column_update_model import DatasetSchemaColumnUpdateModel
from data_repo_client.models.dataset_schema_update_model import DatasetSchemaUpdateModel
from data_repo_client.models.dataset_schema_update_model_changes import DatasetSchemaUpdateModelChanges
from data_repo_client.models.dataset_specification_model import DatasetSpecificationModel
from data_repo_client.models.dataset_summary_model import DatasetSummaryModel
from data_repo_client.models.date_partition_options_model import DatePartitionOptionsModel
from data_repo_client.models.delete_response_model import DeleteResponseModel
from data_repo_client.models.directory_detail_model import DirectoryDetailModel
from data_repo_client.models.drs_alias_model import DrsAliasModel
from data_repo_client.models.duos_firecloud_group_model import DuosFirecloudGroupModel
from data_repo_client.models.duos_firecloud_groups_sync_response import DuosFirecloudGroupsSyncResponse
from data_repo_client.models.enumerate_billing_profile_model import EnumerateBillingProfileModel
from data_repo_client.models.enumerate_dataset_model import EnumerateDatasetModel
from data_repo_client.models.enumerate_snapshot_access_request import EnumerateSnapshotAccessRequest
from data_repo_client.models.enumerate_snapshot_model import EnumerateSnapshotModel
from data_repo_client.models.enumerate_sort_by_param import EnumerateSortByParam
from data_repo_client.models.error_model import ErrorModel
from data_repo_client.models.file_detail_model import FileDetailModel
from data_repo_client.models.file_load_model import FileLoadModel
from data_repo_client.models.file_model import FileModel
from data_repo_client.models.file_model_type import FileModelType
from data_repo_client.models.iam_resource_type_enum import IamResourceTypeEnum
from data_repo_client.models.inaccessible_workspace_policy_model import InaccessibleWorkspacePolicyModel
from data_repo_client.models.ingest_request_model import IngestRequestModel
from data_repo_client.models.ingest_response_model import IngestResponseModel
from data_repo_client.models.int_partition_options_model import IntPartitionOptionsModel
from data_repo_client.models.job_model import JobModel
from data_repo_client.models.journal_entry_model import JournalEntryModel
from data_repo_client.models.policy_member_request import PolicyMemberRequest
from data_repo_client.models.policy_model import PolicyModel
from data_repo_client.models.policy_response import PolicyResponse
from data_repo_client.models.query_column_statistics_request_model import QueryColumnStatisticsRequestModel
from data_repo_client.models.query_data_request_model import QueryDataRequestModel
from data_repo_client.models.relationship_model import RelationshipModel
from data_repo_client.models.relationship_term_model import RelationshipTermModel
from data_repo_client.models.repository_configuration_model import RepositoryConfigurationModel
from data_repo_client.models.repository_status_model import RepositoryStatusModel
from data_repo_client.models.repository_status_model_systems import RepositoryStatusModelSystems
from data_repo_client.models.resource_locks import ResourceLocks
from data_repo_client.models.resource_policy_model import ResourcePolicyModel
from data_repo_client.models.sam_policy_model import SamPolicyModel
from data_repo_client.models.snapshot_access_request import SnapshotAccessRequest
from data_repo_client.models.snapshot_access_request_response import SnapshotAccessRequestResponse
from data_repo_client.models.snapshot_access_request_status import SnapshotAccessRequestStatus
from data_repo_client.models.snapshot_builder_cohort import SnapshotBuilderCohort
from data_repo_client.models.snapshot_builder_concept import SnapshotBuilderConcept
from data_repo_client.models.snapshot_builder_count_request import SnapshotBuilderCountRequest
from data_repo_client.models.snapshot_builder_count_response import SnapshotBuilderCountResponse
from data_repo_client.models.snapshot_builder_count_response_result import SnapshotBuilderCountResponseResult
from data_repo_client.models.snapshot_builder_criteria import SnapshotBuilderCriteria
from data_repo_client.models.snapshot_builder_criteria_group import SnapshotBuilderCriteriaGroup
from data_repo_client.models.snapshot_builder_dataset_concept_set import SnapshotBuilderDatasetConceptSet
from data_repo_client.models.snapshot_builder_domain_criteria import SnapshotBuilderDomainCriteria
from data_repo_client.models.snapshot_builder_domain_criteria_all_of import SnapshotBuilderDomainCriteriaAllOf
from data_repo_client.models.snapshot_builder_domain_option import SnapshotBuilderDomainOption
from data_repo_client.models.snapshot_builder_domain_option_all_of import SnapshotBuilderDomainOptionAllOf
from data_repo_client.models.snapshot_builder_feature_value_group import SnapshotBuilderFeatureValueGroup
from data_repo_client.models.snapshot_builder_get_concept_hierarchy_response import SnapshotBuilderGetConceptHierarchyResponse
from data_repo_client.models.snapshot_builder_get_concepts_response import SnapshotBuilderGetConceptsResponse
from data_repo_client.models.snapshot_builder_option import SnapshotBuilderOption
from data_repo_client.models.snapshot_builder_parent_concept import SnapshotBuilderParentConcept
from data_repo_client.models.snapshot_builder_program_data_list_criteria import SnapshotBuilderProgramDataListCriteria
from data_repo_client.models.snapshot_builder_program_data_list_criteria_all_of import SnapshotBuilderProgramDataListCriteriaAllOf
from data_repo_client.models.snapshot_builder_program_data_list_item import SnapshotBuilderProgramDataListItem
from data_repo_client.models.snapshot_builder_program_data_list_option import SnapshotBuilderProgramDataListOption
from data_repo_client.models.snapshot_builder_program_data_list_option_all_of import SnapshotBuilderProgramDataListOptionAllOf
from data_repo_client.models.snapshot_builder_program_data_option import SnapshotBuilderProgramDataOption
from data_repo_client.models.snapshot_builder_program_data_option_all_of import SnapshotBuilderProgramDataOptionAllOf
from data_repo_client.models.snapshot_builder_program_data_range_criteria import SnapshotBuilderProgramDataRangeCriteria
from data_repo_client.models.snapshot_builder_program_data_range_criteria_all_of import SnapshotBuilderProgramDataRangeCriteriaAllOf
from data_repo_client.models.snapshot_builder_program_data_range_option import SnapshotBuilderProgramDataRangeOption
from data_repo_client.models.snapshot_builder_program_data_range_option_all_of import SnapshotBuilderProgramDataRangeOptionAllOf
from data_repo_client.models.snapshot_builder_request import SnapshotBuilderRequest
from data_repo_client.models.snapshot_builder_settings import SnapshotBuilderSettings
from data_repo_client.models.snapshot_export_response_model import SnapshotExportResponseModel
from data_repo_client.models.snapshot_export_response_model_format import SnapshotExportResponseModelFormat
from data_repo_client.models.snapshot_export_response_model_format_parquet import SnapshotExportResponseModelFormatParquet
from data_repo_client.models.snapshot_export_response_model_format_parquet_location import SnapshotExportResponseModelFormatParquetLocation
from data_repo_client.models.snapshot_export_response_model_format_parquet_location_tables import SnapshotExportResponseModelFormatParquetLocationTables
from data_repo_client.models.snapshot_export_response_model_format_workspace import SnapshotExportResponseModelFormatWorkspace
from data_repo_client.models.snapshot_ids_and_roles_model import SnapshotIdsAndRolesModel
from data_repo_client.models.snapshot_link_duos_dataset_response import SnapshotLinkDuosDatasetResponse
from data_repo_client.models.snapshot_model import SnapshotModel
from data_repo_client.models.snapshot_patch_request_model import SnapshotPatchRequestModel
from data_repo_client.models.snapshot_preview_model import SnapshotPreviewModel
from data_repo_client.models.snapshot_request_asset_model import SnapshotRequestAssetModel
from data_repo_client.models.snapshot_request_contents_model import SnapshotRequestContentsModel
from data_repo_client.models.snapshot_request_model import SnapshotRequestModel
from data_repo_client.models.snapshot_request_model_policies import SnapshotRequestModelPolicies
from data_repo_client.models.snapshot_request_query_model import SnapshotRequestQueryModel
from data_repo_client.models.snapshot_request_row_id_model import SnapshotRequestRowIdModel
from data_repo_client.models.snapshot_request_row_id_table_model import SnapshotRequestRowIdTableModel
from data_repo_client.models.snapshot_retrieve_include_model import SnapshotRetrieveIncludeModel
from data_repo_client.models.snapshot_source_model import SnapshotSourceModel
from data_repo_client.models.snapshot_summary_model import SnapshotSummaryModel
from data_repo_client.models.sql_sort_direction_asc_default import SqlSortDirectionAscDefault
from data_repo_client.models.sql_sort_direction_desc_default import SqlSortDirectionDescDefault
from data_repo_client.models.storage_resource_model import StorageResourceModel
from data_repo_client.models.table_data_type import TableDataType
from data_repo_client.models.table_model import TableModel
from data_repo_client.models.tag_count import TagCount
from data_repo_client.models.tag_count_result_model import TagCountResultModel
from data_repo_client.models.tag_update_request_model import TagUpdateRequestModel
from data_repo_client.models.transaction_close_model import TransactionCloseModel
from data_repo_client.models.transaction_create_model import TransactionCreateModel
from data_repo_client.models.transaction_model import TransactionModel
from data_repo_client.models.unlock_resource_request import UnlockResourceRequest
from data_repo_client.models.upgrade_model import UpgradeModel
from data_repo_client.models.upgrade_response_model import UpgradeResponseModel
from data_repo_client.models.user_status_info import UserStatusInfo
from data_repo_client.models.workspace_policy_model import WorkspacePolicyModel

